initialize_chains: Initialize pi, f, and theta based on priors Note: Depends on...

Description Usage Value

View source: R/prior_functions.R

Description

Initialize pi, f, and theta based on priors Note: Depends on prior_pi, prior_f, and prior_theta being defined in this namespace

Usage

1

Value

list of ititial values for logit_pi, logit_f, and logit_theta


kholsinger/Hickory documentation built on Jan. 9, 2022, 6:30 p.m.